@@ -14,13 +14,13 @@ try:
     from pathlib import Path
 
     dotenv_path = find_dotenv(raise_error_if_not_found=True)
+    dotenv_result = load_dotenv(dotenv_path=dotenv_path)
     print('dotenv[wsgi] configuration %s from "%s"' % ('loaded' if dotenv_result else 'not loaded', dotenv_path))
-    load_dotenv(dotenv_path=dotenv_path)
-
-    os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 except BaseException as e:
-    logging.error('Dotenv file could not loaded')
-    # logging.exception(e)
-    # traceback.print_exc()
+    logging.error('dotenv[wsgi] configuration could not loaded')
+    logging.exception(e)
+    os.environ.setdefault("KRYNEGGER_CONFIGURATION", "development")
+finally:
+    os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 
 application = get_wsgi_application()
